@@ -15,12 +15,13 @@ from typing import Any, Callable, Dict, Optional
 
 from torch import Tensor, tensor
 
-from torchmetrics.functional.audio.pit import pit
+from torchmetrics.functional.audio.pit import permutation_invariant_training
 from torchmetrics.metric import Metric
 
 
-class PIT(Metric):
-    """Permutation invariant training (PIT). The PIT implements the famous Permutation Invariant Training method.
+class PermutationInvariantTraining(Metric):
+    """Permutation invariant training (PermutationInvariantTraining). The PermutationInvariantTraining implements
+    the famous Permutation Invariant Training method.
 
     [1] in speech separation field in order to calculate audio metrics in a permutation invariant way.
 
@@ -31,35 +32,31 @@ class PIT(Metric):
 
     Args:
         metric_func:
-            a metric function accept a batch of target and estimate, i.e. metric_func(preds[:, i, ...],
-            target[:, j, ...]), and returns a batch of metric tensors [batch]
+            a metric function accept a batch of target and estimate,
+            i.e. ``metric_func(preds[:, i, ...], target[:, j, ...])``, and returns a batch of metric tensors ``[batch]``
         eval_func:
             the function to find the best permutation, can be 'min' or 'max', i.e. the smaller the better
             or the larger the better.
         compute_on_step:
-            Forward only calls ``update()`` and returns None if this is set to False. default: True
-        dist_sync_on_step:
-            Synchronize metric state across processes at each ``forward()``
-            before returning the value at the step.
-        process_group:
-            Specify the process group on which synchronization is called. default: None (which selects the entire world)
-        dist_sync_fn:
-            Callback that performs the allgather operation on the metric state. When `None`, DDP
-            will be used to perform the allgather.
-        kwargs:
-            additional args for metric_func
+            Forward only calls ``update()`` and returns None if this is set to False.
+
+            .. deprecated:: v0.8
+                Argument has no use anymore and will be removed v0.9.
+
+        kwargs: Additional keyword arguments for either the ``metric_func`` or distributed communication,
+            see :ref:`Metric kwargs` for more info.
 
     Returns:
-        average PIT metric
+        average PermutationInvariantTraining metric
 
     Example:
         >>> import torch
-        >>> from torchmetrics import PIT
-        >>> from torchmetrics.functional import si_snr
+        >>> from torchmetrics import PermutationInvariantTraining
+        >>> from torchmetrics.functional import scale_invariant_signal_noise_ratio
         >>> _ = torch.manual_seed(42)
         >>> preds = torch.randn(3, 2, 5) # [batch, spk, time]
         >>> target = torch.randn(3, 2, 5) # [batch, spk, time]
-        >>> pit = PIT(si_snr, 'max')
+        >>> pit = PermutationInvariantTraining(scale_invariant_signal_noise_ratio, 'max')
         >>> pit(preds, target)
         tensor(-2.1065)
 
@@ -77,18 +74,15 @@ class PIT(Metric):
         self,
         metric_func: Callable,
         eval_func: str = "max",
-        compute_on_step: bool = True,
-        dist_sync_on_step: bool = False,
-        process_group: Optional[Any] = None,
-        dist_sync_fn: Optional[Callable[[Tensor], Tensor]] = None,
+        compute_on_step: Optional[bool] = None,
         **kwargs: Dict[str, Any],
     ) -> None:
-        super().__init__(
-            compute_on_step=compute_on_step,
-            dist_sync_on_step=dist_sync_on_step,
-            process_group=process_group,
-            dist_sync_fn=dist_sync_fn,
-        )
+        base_kwargs: Dict[str, Any] = {
+            "dist_sync_on_step": kwargs.pop("dist_sync_on_step", False),
+            "process_group": kwargs.pop("process_group", None),
+            "dist_sync_fn": kwargs.pop("dist_sync_fn", None),
+        }
+        super().__init__(compute_on_step=compute_on_step, **base_kwargs)
         self.metric_func = metric_func
         self.eval_func = eval_func
         self.kwargs = kwargs
@@ -103,11 +97,11 @@ class PIT(Metric):
             preds: Predictions from model
             target: Ground truth values
         """
-        pit_metric = pit(preds, target, self.metric_func, self.eval_func, **self.kwargs)[0]
+        pit_metric = permutation_invariant_training(preds, target, self.metric_func, self.eval_func, **self.kwargs)[0]
 
         self.sum_pit_metric += pit_metric.sum()
         self.total += pit_metric.numel()
 
     def compute(self) -> Tensor:
-        """Computes average PIT metric."""
+        """Computes average PermutationInvariantTraining metric."""
         return self.sum_pit_metric / self.total
