@@ -11,7 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Any, Callable, List, Optional
+from typing import Any, Dict, List, Optional
 
 import torch
 from torch import Tensor
@@ -47,32 +47,29 @@ class AUROC(Metric):
         with an warning.
 
     Args:
-       num_classes: integer with number of classes for multi-label and multiclass problems.
-           Should be set to ``None`` for binary problems
-       pos_label: integer determining the positive class. Default is ``None``
-           which for binary problem is translate to 1. For multiclass problems
-           this argument should not be set as we iteratively change it in the
-           range [0,num_classes-1]
-       average:
-           - ``'micro'`` computes metric globally. Only works for multilabel problems
-           - ``'macro'`` computes metric for each class and uniformly averages them
-           - ``'weighted'`` computes metric for each class and does a weighted-average,
-             where each class is weighted by their support (accounts for class imbalance)
-           - ``None`` computes and returns the metric per class
-       max_fpr:
-           If not ``None``, calculates standardized partial AUC over the
-           range [0, max_fpr]. Should be a float between 0 and 1.
-       compute_on_step:
-           Forward only calls ``update()`` and return None if this is set to False.
-       dist_sync_on_step:
-           Synchronize metric state across processes at each ``forward()``
-           before returning the value at the step.
-       process_group:
-           Specify the process group on which synchronization is called.
+        num_classes: integer with number of classes for multi-label and multiclass problems.
 
-       dist_sync_fn:
-           Callback that performs the allgather operation on the metric state. When ``None``, DDP
-           will be used to perform the allgather
+            Should be set to ``None`` for binary problems
+        pos_label: integer determining the positive class. Default is ``None``
+            which for binary problem is translated to 1. For multiclass problems
+            this argument should not be set as we iteratively change it in the
+            range ``[0, num_classes-1]``
+        average:
+            - ``'micro'`` computes metric globally. Only works for multilabel problems
+            - ``'macro'`` computes metric for each class and uniformly averages them
+            - ``'weighted'`` computes metric for each class and does a weighted-average,
+              where each class is weighted by their support (accounts for class imbalance)
+            - ``None`` computes and returns the metric per class
+        max_fpr:
+            If not ``None``, calculates standardized partial AUC over the
+            range ``[0, max_fpr]``. Should be a float between 0 and 1.
+        compute_on_step:
+            Forward only calls ``update()`` and returns None if this is set to False.
+
+            .. deprecated:: v0.8
+                Argument has no use anymore and will be removed v0.9.
+
+        kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
     Raises:
         ValueError:
@@ -80,7 +77,7 @@ class AUROC(Metric):
         ValueError:
             If ``max_fpr`` is not a ``float`` in the range ``(0, 1]``.
         RuntimeError:
-            If ``PyTorch version`` is ``below 1.6`` since max_fpr requires ``torch.bucketize``
+            If ``PyTorch version`` is ``below 1.6`` since ``max_fpr`` requires ``torch.bucketize``
             which is not available below 1.6.
         ValueError:
             If the mode of data (binary, multi-label, multi-class) changes between batches.
@@ -116,17 +113,10 @@ class AUROC(Metric):
         pos_label: Optional[int] = None,
         average: Optional[str] = "macro",
         max_fpr: Optional[float] = None,
-        compute_on_step: bool = True,
-        dist_sync_on_step: bool = False,
-        process_group: Optional[Any] = None,
-        dist_sync_fn: Callable = None,
+        compute_on_step: Optional[bool] = None,
+        **kwargs: Dict[str, Any],
     ) -> None:
-        super().__init__(
-            compute_on_step=compute_on_step,
-            dist_sync_on_step=dist_sync_on_step,
-            process_group=process_group,
-            dist_sync_fn=dist_sync_fn,
-        )
+        super().__init__(compute_on_step=compute_on_step, **kwargs)
 
         self.num_classes = num_classes
         self.pos_label = pos_label
