@@ -11,7 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Any, List, Optional, Tuple, Union
+from typing import Any, Dict, List, Optional, Tuple, Union
 
 import torch
 from torch import Tensor
@@ -62,16 +62,16 @@ class BinnedPrecisionRecallCurve(Metric):
             It is used for computation will lead to more detailed curve and accurate estimates,
             but will be slower and consume more memory.
         compute_on_step:
-            Forward only calls ``update()`` and return None if this is set to False.
-        dist_sync_on_step:
-            Synchronize metric state across processes at each ``forward()``
-            before returning the value at the step.
-        process_group:
-            Specify the process group on which synchronization is called.
+            Forward only calls ``update()`` and returns None if this is set to False.
+
+            .. deprecated:: v0.8
+                Argument has no use anymore and will be removed v0.9.
+
+        kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
     Raises:
         ValueError:
-            If ``thresholds`` is not a int, list or tensor
+            If ``thresholds`` is not a ``int``, ``list`` or ``tensor``
 
     Example (binary case):
         >>> from torchmetrics import BinnedPrecisionRecallCurve
@@ -121,16 +121,11 @@ class BinnedPrecisionRecallCurve(Metric):
     def __init__(
         self,
         num_classes: int,
-        thresholds: Union[int, Tensor, List[float], None] = None,
-        compute_on_step: bool = True,
-        dist_sync_on_step: bool = False,
-        process_group: Optional[Any] = None,
+        thresholds: Union[int, Tensor, List[float]] = 100,
+        compute_on_step: Optional[bool] = None,
+        **kwargs: Dict[str, Any],
     ) -> None:
-        super().__init__(
-            compute_on_step=compute_on_step,
-            dist_sync_on_step=dist_sync_on_step,
-            process_group=process_group,
-        )
+        super().__init__(compute_on_step=compute_on_step, **kwargs)
 
         self.num_classes = num_classes
         if isinstance(thresholds, int):
@@ -170,8 +165,8 @@ class BinnedPrecisionRecallCurve(Metric):
         for i in range(self.num_thresholds):
             predictions = preds >= self.thresholds[i]
             self.TPs[:, i] += (target & predictions).sum(dim=0)
-            self.FPs[:, i] += ((~target) & (predictions)).sum(dim=0)
-            self.FNs[:, i] += ((target) & (~predictions)).sum(dim=0)
+            self.FPs[:, i] += ((~target) & predictions).sum(dim=0)
+            self.FNs[:, i] += (target & (~predictions)).sum(dim=0)
 
     def compute(self) -> Union[Tuple[Tensor, Tensor, Tensor], Tuple[List[Tensor], List[Tensor], List[Tensor]]]:
         """Returns float tensor of size n_classes."""
@@ -204,19 +199,21 @@ class BinnedAveragePrecision(BinnedPrecisionRecallCurve):
     - ``target`` (long tensor): ``(N, ...)`` with integer labels
 
     Args:
-        num_classes: integer with number of classes. Not nessesary to provide
-            for binary problems.
+        num_classes: integer with number of classes. Not nessesary to provide for binary problems.
         thresholds: list or tensor with specific thresholds or a number of bins from linear sampling.
             It is used for computation will lead to more detailed curve and accurate estimates,
             but will be slower and consume more memory
         compute_on_step:
-            Forward only calls ``update()`` and return None if this is set to False.
-        process_group:
-            Specify the process group on which synchronization is called.
+            Forward only calls ``update()`` and returns None if this is set to False.
+
+            .. deprecated:: v0.8
+                Argument has no use anymore and will be removed v0.9.
+
+        kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
     Raises:
         ValueError:
-            If ``thresholds`` is not a list or tensor
+            If ``thresholds`` is not a ``list`` or ``tensor``
 
     Example (binary case):
         >>> from torchmetrics import BinnedAveragePrecision
@@ -256,15 +253,18 @@ class BinnedRecallAtFixedPrecision(BinnedPrecisionRecallCurve):
     - ``target`` (long tensor): ``(N, ...)`` with integer labels
 
     Args:
-        num_classes: integer with number of classes. Provide 1 for for binary problems.
+        num_classes: integer with number of classes. Provide 1 for binary problems.
         min_precision: float value specifying minimum precision threshold.
         thresholds: list or tensor with specific thresholds or a number of bins from linear sampling.
             It is used for computation will lead to more detailed curve and accurate estimates,
             but will be slower and consume more memory
         compute_on_step:
-            Forward only calls ``update()`` and return None if this is set to False.
-        process_group:
-            Specify the process group on which synchronization is called.
+            Forward only calls ``update()`` and returns None if this is set to False.
+
+            .. deprecated:: v0.8
+                Argument has no use anymore and will be removed v0.9.
+
+        kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
     Raises:
         ValueError:
@@ -294,18 +294,11 @@ class BinnedRecallAtFixedPrecision(BinnedPrecisionRecallCurve):
         self,
         num_classes: int,
         min_precision: float,
-        thresholds: Union[int, Tensor, List[float], None] = None,
-        compute_on_step: bool = True,
-        dist_sync_on_step: bool = False,
-        process_group: Optional[Any] = None,
+        thresholds: Union[int, Tensor, List[float]] = 100,
+        compute_on_step: Optional[bool] = None,
+        **kwargs: Dict[str, Any],
     ) -> None:
-        super().__init__(
-            num_classes=num_classes,
-            thresholds=thresholds,
-            compute_on_step=compute_on_step,
-            dist_sync_on_step=dist_sync_on_step,
-            process_group=process_group,
-        )
+        super().__init__(num_classes=num_classes, thresholds=thresholds, compute_on_step=compute_on_step, **kwargs)
         self.min_precision = min_precision
 
     def compute(self) -> Tuple[Tensor, Tensor]:  # type: ignore
