@@ -11,7 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Any, Optional
+from typing import Any, Dict, Optional
 
 import torch
 from torch import Tensor
@@ -21,10 +21,10 @@ from torchmetrics.metric import Metric
 
 
 class ConfusionMatrix(Metric):
-    r"""
-    Computes the `confusion matrix`_.  Works with binary,
-    multiclass, and multilabel data.  Accepts probabilities or logits from a model output or integer class
-    values in prediction. Works with multi-dimensional preds and target, but it should be noted that
+    r"""Computes the `confusion matrix`_.
+
+    Works with binary, multiclass, and multilabel data. Accepts probabilities or logits from a model output
+    or integer class values in prediction. Works with multi-dimensional preds and target, but it should be noted that
     additional dimensions will be flattened.
 
     Forward accepts
@@ -37,12 +37,12 @@ class ConfusionMatrix(Metric):
 
     If preds has an extra dimension as in the case of multi-class scores we perform an argmax on ``dim=1``.
 
-    If working with multilabel data, setting the `is_multilabel` argument to `True` will make sure that a
+    If working with multilabel data, setting the ``is_multilabel`` argument to ``True`` will make sure that a
     `confusion matrix gets calculated per label`_.
 
     Args:
         num_classes: Number of classes in the dataset.
-        normalize: Normalization mode for confusion matrix. Choose from
+        normalize: Normalization mode for confusion matrix. Choose from:
 
             - ``None`` or ``'none'``: no normalization (default)
             - ``'true'``: normalization over the targets (most commonly used)
@@ -50,18 +50,17 @@ class ConfusionMatrix(Metric):
             - ``'all'``: normalization over the whole matrix
 
         threshold:
-            Threshold for transforming probability or logit predictions to binary (0,1) predictions, in the case
-            of binary or multi-label inputs. Default value of 0.5 corresponds to input being probabilities.
+            Threshold for transforming probability or logit predictions to binary ``(0,1)`` predictions, in the case
+            of binary or multi-label inputs. Default value of ``0.5`` corresponds to input being probabilities.
 
-        multilabel:
-            determines if data is multilabel or not.
+        multilabel: determines if data is multilabel or not.
         compute_on_step:
-            Forward only calls ``update()`` and return None if this is set to False.
-        dist_sync_on_step:
-            Synchronize metric state across processes at each ``forward()``
-            before returning the value at the step.
-        process_group:
-            Specify the process group on which synchronization is called.
+            Forward only calls ``update()`` and returns None if this is set to False.
+
+            .. deprecated:: v0.8
+                Argument has no use anymore and will be removed v0.9.
+
+        kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
     Example (binary data):
         >>> from torchmetrics import ConfusionMatrix
@@ -100,15 +99,10 @@ class ConfusionMatrix(Metric):
         normalize: Optional[str] = None,
         threshold: float = 0.5,
         multilabel: bool = False,
-        compute_on_step: bool = True,
-        dist_sync_on_step: bool = False,
-        process_group: Optional[Any] = None,
+        compute_on_step: Optional[bool] = None,
+        **kwargs: Dict[str, Any],
     ) -> None:
-        super().__init__(
-            compute_on_step=compute_on_step,
-            dist_sync_on_step=dist_sync_on_step,
-            process_group=process_group,
-        )
+        super().__init__(compute_on_step=compute_on_step, **kwargs)
         self.num_classes = num_classes
         self.normalize = normalize
         self.threshold = threshold
@@ -138,7 +132,7 @@ class ConfusionMatrix(Metric):
         """Computes confusion matrix.
 
         Returns:
-            If `multilabel=False` this will be a `[n_classes, n_classes]` tensor and if `multilabel=True`
-            this will be a `[n_classes, 2, 2]` tensor
+            If ``multilabel=False`` this will be a ``[n_classes, n_classes]`` tensor and if ``multilabel=True``
+            this will be a ``[n_classes, 2, 2]`` tensor.
         """
         return _confusion_matrix_compute(self.confmat, self.normalize)
