@@ -11,10 +11,9 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Any, Callable, Optional
+from typing import Any, Dict, Optional
 
 import torch
-from deprecate import deprecated, void
 from torch import Tensor
 
 from torchmetrics.functional.classification.matthews_corrcoef import (
@@ -22,14 +21,12 @@ from torchmetrics.functional.classification.matthews_corrcoef import (
     _matthews_corrcoef_update,
 )
 from torchmetrics.metric import Metric
-from torchmetrics.utilities import _future_warning
 
 
 class MatthewsCorrCoef(Metric):
-    r"""
-    Calculates `Matthews correlation coefficient`_ that measures
-    the general correlation or quality of a classification. In the binary case it
-    is defined as:
+    r"""Calculates `Matthews correlation coefficient`_ that measures the general correlation or quality of a classification.
+
+    In the binary case it is defined as:
 
     .. math::
         MCC = \frac{TP*TN - FP*FN}{\sqrt{(TP+FP)*(TP+FN)*(TN+FP)*(TN+FN)}}
@@ -53,18 +50,14 @@ class MatthewsCorrCoef(Metric):
 
     Args:
         num_classes: Number of classes in the dataset.
-        threshold:
-            Threshold value for binary or multi-label probabilites.
+        threshold: Threshold value for binary or multi-label probabilites.
         compute_on_step:
-            Forward only calls ``update()`` and return None if this is set to False.
-        dist_sync_on_step:
-            Synchronize metric state across processes at each ``forward()``
-            before returning the value at the step.
-        process_group:
-            Specify the process group on which synchronization is called.
-        dist_sync_fn:
-            Callback that performs the allgather operation on the metric state. When ``None``, DDP
-            will be used to perform the allgather
+            Forward only calls ``update()`` and returns None if this is set to False.
+
+            .. deprecated:: v0.8
+                Argument has no use anymore and will be removed v0.9.
+
+        kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
     Example:
         >>> from torchmetrics import MatthewsCorrCoef
@@ -83,17 +76,10 @@ class MatthewsCorrCoef(Metric):
         self,
         num_classes: int,
         threshold: float = 0.5,
-        compute_on_step: bool = True,
-        dist_sync_on_step: bool = False,
-        process_group: Optional[Any] = None,
-        dist_sync_fn: Callable = None,
+        compute_on_step: Optional[bool] = None,
+        **kwargs: Dict[str, Any],
     ) -> None:
-        super().__init__(
-            compute_on_step=compute_on_step,
-            dist_sync_on_step=dist_sync_on_step,
-            process_group=process_group,
-            dist_sync_fn=dist_sync_fn,
-        )
+        super().__init__(compute_on_step=compute_on_step, **kwargs)
         self.num_classes = num_classes
         self.threshold = threshold
 
@@ -112,29 +98,3 @@ class MatthewsCorrCoef(Metric):
     def compute(self) -> Tensor:
         """Computes matthews correlation coefficient."""
         return _matthews_corrcoef_compute(self.confmat)
-
-
-class MatthewsCorrcoef(MatthewsCorrCoef):
-    """Calculates `Matthews correlation coefficient`_ that measures the general correlation or quality of a
-    classification.
-
-    Example:
-        >>> matthews_corrcoef = MatthewsCorrcoef(num_classes=2)
-        >>> matthews_corrcoef(torch.tensor([0, 1, 0, 0]), torch.tensor([1, 1, 0, 0]))
-        tensor(0.5774)
-
-    .. deprecated:: v0.7
-        Renamed in favor of :class:`torchmetrics.MatthewsCorrCoef`. Will be removed in v0.8.
-    """
-
-    @deprecated(target=MatthewsCorrCoef, deprecated_in="0.7", remove_in="0.8", stream=_future_warning)
-    def __init__(
-        self,
-        num_classes: int,
-        threshold: float = 0.5,
-        compute_on_step: bool = True,
-        dist_sync_on_step: bool = False,
-        process_group: Optional[Any] = None,
-        dist_sync_fn: Callable = None,
-    ) -> None:
-        void(num_classes, threshold, compute_on_step, dist_sync_on_step, process_group, dist_sync_fn)
