@@ -11,4 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from torchmetrics.detection.map import MAP  # noqa: F401
+from torchmetrics.utilities.imports import _TORCHVISION_GREATER_EQUAL_0_8
+
+if _TORCHVISION_GREATER_EQUAL_0_8:
+    from torchmetrics.detection.mean_ap import MeanAveragePrecision  # noqa: F401
