@@ -12,7 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 import numpy as np
-from deprecate import deprecated, void
 
 from torchmetrics.utilities.imports import _PESQ_AVAILABLE
 
@@ -23,15 +22,9 @@ else:
 import torch
 from torch import Tensor
 
-from torchmetrics.utilities import _future_warning
 from torchmetrics.utilities.checks import _check_same_shape
 
-__doctest_requires__ = {
-    (
-        "perceptual_evaluation_speech_quality",
-        "pesq",
-    ): ["pesq"]
-}
+__doctest_requires__ = {("perceptual_evaluation_speech_quality",): ["pesq"]}
 
 
 def perceptual_evaluation_speech_quality(
@@ -48,16 +41,11 @@ def perceptual_evaluation_speech_quality(
         most likely have to reinstall ``pesq``.
 
     Args:
-        preds:
-            shape ``[...,time]``
-        target:
-            shape ``[...,time]``
-        fs:
-            sampling frequency, should be 16000 or 8000 (Hz)
-        mode:
-            'wb' (wide-band) or 'nb' (narrow-band)
-        keep_same_device:
-            whether to move the pesq value to the device of preds
+        preds: shape ``[...,time]``
+        target: shape ``[...,time]``
+        fs: sampling frequency, should be 16000 or 8000 (Hz)
+        mode: ``'wb'`` (wide-band) or ``'nb'`` (narrow-band)
+        keep_same_device: whether to move the pesq value to the device of preds
 
     Returns:
         pesq value of shape [...]
@@ -111,23 +99,3 @@ def perceptual_evaluation_speech_quality(
         pesq_val = pesq_val.to(preds.device)
 
     return pesq_val
-
-
-@deprecated(target=perceptual_evaluation_speech_quality, deprecated_in="0.7", remove_in="0.8", stream=_future_warning)
-def pesq(preds: Tensor, target: Tensor, fs: int, mode: str, keep_same_device: bool = False) -> Tensor:
-    r"""PESQ (Perceptual Evaluation of Speech Quality)
-
-    .. deprecated:: v0.7
-        Use :func:`torchmetrics.functional.audio.perceptual_evaluation_speech_quality`. Will be removed in v0.8.
-
-    Example:
-        >>> import torch
-        >>> g = torch.manual_seed(1)
-        >>> preds = torch.randn(8000)
-        >>> target = torch.randn(8000)
-        >>> pesq(preds, target, 8000, 'nb')
-        tensor(2.2076)
-        >>> pesq(preds, target, 16000, 'wb')
-        tensor(1.7359)
-    """
-    return void(preds, target, fs, mode, keep_same_device)
