@@ -11,14 +11,16 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+
 import torch
 from torch import Tensor
 
+from torchmetrics.functional.audio.sdr import scale_invariant_signal_distortion_ratio
 from torchmetrics.utilities.checks import _check_same_shape
 
 
-def snr(preds: Tensor, target: Tensor, zero_mean: bool = False) -> Tensor:
-    r""" `Signal-to-noise ratio (SNR) <https://en.wikipedia.org/wiki/Signal-to-noise_ratio>`_:
+def signal_noise_ratio(preds: Tensor, target: Tensor, zero_mean: bool = False) -> Tensor:
+    r"""Signal-to-noise ratio (SNR_):
 
     .. math::
         \text{SNR} = \frac{P_{signal}}{P_{noise}}
@@ -28,30 +30,27 @@ def snr(preds: Tensor, target: Tensor, zero_mean: bool = False) -> Tensor:
     SNR means that the audio is clear.
 
     Args:
-        preds:
-            shape ``[...,time]``
-        target:
-            shape ``[...,time]``
-        zero_mean:
-            if to zero mean target and preds or not
+        preds: shape ``[...,time]``
+        target: shape ``[...,time]``
+        zero_mean: if to zero mean target and preds or not
 
     Returns:
         snr value of shape [...]
 
     Example:
-        >>> from torchmetrics.functional.audio import snr
+        >>> from torchmetrics.functional.audio import signal_noise_ratio
         >>> target = torch.tensor([3.0, -0.5, 2.0, 7.0])
         >>> preds = torch.tensor([2.5, 0.0, 2.0, 8.0])
-        >>> snr_val = snr(preds, target)
-        >>> snr_val
+        >>> signal_noise_ratio(preds, target)
         tensor(16.1805)
 
     References:
         [1] Le Roux, Jonathan, et al. "SDR half-baked or well done." IEEE International Conference on Acoustics, Speech
-         and Signal Processing (ICASSP) 2019.
+        and Signal Processing (ICASSP) 2019.
+
     """
     _check_same_shape(preds, target)
-    EPS = torch.finfo(preds.dtype).eps
+    eps = torch.finfo(preds.dtype).eps
 
     if zero_mean:
         target = target - torch.mean(target, dim=-1, keepdim=True)
@@ -59,7 +58,33 @@ def snr(preds: Tensor, target: Tensor, zero_mean: bool = False) -> Tensor:
 
     noise = target - preds
 
-    snr_value = (torch.sum(target**2, dim=-1) + EPS) / (torch.sum(noise**2, dim=-1) + EPS)
+    snr_value = (torch.sum(target**2, dim=-1) + eps) / (torch.sum(noise**2, dim=-1) + eps)
     snr_value = 10 * torch.log10(snr_value)
 
     return snr_value
+
+
+def scale_invariant_signal_noise_ratio(preds: Tensor, target: Tensor) -> Tensor:
+    """Scale-invariant signal-to-noise ratio (SI-SNR).
+
+    Args:
+        preds: shape ``[...,time]``
+        target: shape ``[...,time]``
+
+    Returns:
+        si-snr value of shape [...]
+
+    Example:
+        >>> import torch
+        >>> from torchmetrics.functional.audio import scale_invariant_signal_noise_ratio
+        >>> target = torch.tensor([3.0, -0.5, 2.0, 7.0])
+        >>> preds = torch.tensor([2.5, 0.0, 2.0, 8.0])
+        >>> scale_invariant_signal_noise_ratio(preds, target)
+        tensor(15.0918)
+
+    References:
+        [1] Y. Luo and N. Mesgarani, "TaSNet: Time-Domain Audio Separation Network for Real-Time, Single-Channel Speech
+        Separation," 2018 IEEE International Conference on Acoustics, Speech and Signal Processing (ICASSP), 2018, pp.
+        696-700, doi: 10.1109/ICASSP.2018.8462116.
+    """
+    return scale_invariant_signal_distortion_ratio(preds=preds, target=target, zero_mean=True)
