@@ -13,7 +13,6 @@
 # limitations under the License.
 import numpy as np
 import torch
-from deprecate import deprecated, void
 
 from torchmetrics.utilities.imports import _PYSTOI_AVAILABLE
 
@@ -21,10 +20,9 @@ if _PYSTOI_AVAILABLE:
     from pystoi import stoi as stoi_backend
 else:
     stoi_backend = None
-    __doctest_skip__ = ["short_time_objective_intelligibility", "stoi"]
+    __doctest_skip__ = ["short_time_objective_intelligibility"]
 from torch import Tensor
 
-from torchmetrics.utilities import _future_warning
 from torchmetrics.utilities.checks import _check_same_shape
 
 
@@ -39,22 +37,17 @@ def short_time_objective_intelligibility(
     The STOI-measure is intrusive, i.e., a function of the clean and degraded speech signals. STOI may be a good
     alternative to the speech intelligibility index (SII) or the speech transmission index (STI), when you are
     interested in the effect of nonlinear processing to noisy speech, e.g., noise reduction, binary masking algorithms,
-    on speech intelligibility. Description taken from [Cees Taal's website](http://www.ceestaal.nl/code/).
+    on speech intelligibility. Description taken from `Cees Taal's website <http://www.ceestaal.nl/code/>`_.
 
     .. note:: using this metrics requires you to have ``pystoi`` install. Either install as ``pip install
         torchmetrics[audio]`` or ``pip install pystoi``
 
     Args:
-        preds:
-            shape ``[...,time]``
-        target:
-            shape ``[...,time]``
-        fs:
-            sampling frequency (Hz)
-        extended:
-            whether to use the extended STOI described in [4]
-        keep_same_device:
-            whether to move the stoi value to the device of preds
+        preds: shape ``[..., time]``
+        target: shape ``[..., time]``
+        fs: sampling frequency (Hz)
+        extended: whether to use the extended STOI described in [4]
+        keep_same_device: whether to move the stoi value to the device of preds
 
     Returns:
         stoi value of shape [...]
@@ -108,22 +101,3 @@ def short_time_objective_intelligibility(
         stoi_val = stoi_val.to(preds.device)
 
     return stoi_val
-
-
-@deprecated(target=short_time_objective_intelligibility, deprecated_in="0.7", remove_in="0.8", stream=_future_warning)
-def stoi(preds: Tensor, target: Tensor, fs: int, mode: str, keep_same_device: bool = False) -> Tensor:
-    r"""STOI (Short-Time Objective Intelligibility)
-
-    .. deprecated:: v0.7
-        Use :func:`torchmetrics.functional.audio.short_time_objective_intelligibility`. Will be removed in v0.8.
-
-    Example:
-        >>> from torchmetrics.functional.audio.stoi import stoi
-        >>> import torch
-        >>> g = torch.manual_seed(1)
-        >>> preds = torch.randn(8000)
-        >>> target = torch.randn(8000)
-        >>> stoi(preds, target, 8000).float()
-        tensor(-0.0100)
-    """
-    return void(preds, target, fs, mode, keep_same_device)
