@@ -49,10 +49,10 @@ def image_gradients(img: Tensor) -> Tuple[Tensor, Tensor]:
     """Computes `Gradient Computation of Image`_ of a given image using finite difference.
 
     Args:
-        img: An ``(N, C, H, W)`` input tensor where C is the number of image channels
+        img: An ``(N, C, H, W)`` input tensor where ``C`` is the number of image channels
 
     Return:
-        Tuple of (dy, dx) with each gradient of shape ``[N, C, H, W]``
+        Tuple of ``(dy, dx)`` with each gradient of shape ``[N, C, H, W]``
 
     Raises:
         TypeError:
