@@ -18,25 +18,28 @@ from torch import Tensor, tensor
 from torchmetrics.utilities.checks import _check_retrieval_functional_inputs
 
 
-def retrieval_precision(preds: Tensor, target: Tensor, k: Optional[int] = None) -> Tensor:
+def retrieval_precision(preds: Tensor, target: Tensor, k: Optional[int] = None, adaptive_k: bool = False) -> Tensor:
     """Computes the precision metric (for information retrieval). Precision is the fraction of relevant documents
     among all the retrieved documents.
 
     ``preds`` and ``target`` should be of the same shape and live on the same device. If no ``target`` is ``True``,
-    ``0`` is returned. ``target`` must be either `bool` or `integers` and ``preds`` must be `float`,
+    ``0`` is returned. ``target`` must be either `bool` or `integers` and ``preds`` must be ``float``,
     otherwise an error is raised. If you want to measure Precision@K, ``k`` must be a positive integer.
 
     Args:
         preds: estimated probabilities of each document to be relevant.
         target: ground truth about each document being relevant or not.
-        k: consider only the top k elements (default: `None`, which considers them all)
+        k: consider only the top k elements (default: ``None``, which considers them all)
+        adaptive_k: adjust `k` to `min(k, number of documents)` for each query
 
     Returns:
         a single-value tensor with the precision (at ``k``) of the predictions ``preds`` w.r.t. the labels ``target``.
 
     Raises:
         ValueError:
-            If ``k`` parameter is not `None` or an integer larger than 0
+            If ``k`` is not `None` or an integer larger than 0.
+        ValueError:
+            If ``adaptive_k`` is not boolean.
 
     Example:
         >>> preds = tensor([0.2, 0.3, 0.5])
@@ -46,7 +49,10 @@ def retrieval_precision(preds: Tensor, target: Tensor, k: Optional[int] = None)
     """
     preds, target = _check_retrieval_functional_inputs(preds, target)
 
-    if k is None:
+    if not isinstance(adaptive_k, bool):
+        raise ValueError("`adaptive_k` has to be a boolean")
+
+    if k is None or (adaptive_k and k > preds.shape[-1]):
         k = preds.shape[-1]
 
     if not (isinstance(k, int) and k > 0):
