@@ -11,16 +11,14 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Any, List, Optional, Sequence, Tuple
+from typing import Any, Dict, List, Optional, Sequence, Tuple, Union
 
-import torch
-from deprecate import deprecated, void
 from torch import Tensor
 from typing_extensions import Literal
 
 from torchmetrics.functional.image.ssim import _multiscale_ssim_compute, _ssim_compute, _ssim_update
 from torchmetrics.metric import Metric
-from torchmetrics.utilities import _future_warning, rank_zero_warn
+from torchmetrics.utilities import rank_zero_warn
 from torchmetrics.utilities.data import dim_zero_cat
 
 
@@ -28,23 +26,41 @@ class StructuralSimilarityIndexMeasure(Metric):
     """Computes Structual Similarity Index Measure (SSIM_).
 
     Args:
-        kernel_size: size of the gaussian kernel
-        sigma: Standard deviation of the gaussian kernel
+        preds: estimated image
+        target: ground truth image
+        gaussian_kernel: If true (default), a gaussian kernel is used, if false a uniform kernel is used
+        sigma: Standard deviation of the gaussian kernel, anisotropic kernels are possible.
+            Ignored if a uniform kernel is used
+        kernel_size: the size of the uniform kernel, anisotropic kernels are possible.
+            Ignored if a Gaussian kernel is used
         reduction: a method to reduce metric score over labels.
 
-            - ``'elementwise_mean'``: takes the mean (default)
+            - ``'elementwise_mean'``: takes the mean
             - ``'sum'``: takes the sum
-            - ``'none'``: no reduction will be applied
+            - ``'none'`` or ``None``: no reduction will be applied
 
         data_range: Range of the image. If ``None``, it is determined from the image (max - min)
         k1: Parameter of SSIM.
         k2: Parameter of SSIM.
+        return_full_image: If true, the full ``ssim`` image is returned as a second argument.
+            Mutually exclusive with ``return_contrast_sensitivity``
+        return_contrast_sensitivity: If true, the constant term is returned as a second argument.
+            The luminance term can be obtained with luminance=ssim/contrast
+            Mutually exclusive with ``return_full_image``
+        compute_on_step:
+            Forward only calls ``update()`` and returns None if this is set to False.
+
+            .. deprecated:: v0.8
+                Argument has no use anymore and will be removed v0.9.
+
+        kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
     Return:
         Tensor with SSIM score
 
     Example:
         >>> from torchmetrics import StructuralSimilarityIndexMeasure
+        >>> import torch
         >>> preds = torch.rand([16, 1, 16, 16])
         >>> target = preds * 0.75
         >>> ssim = StructuralSimilarityIndexMeasure()
@@ -58,21 +74,19 @@ class StructuralSimilarityIndexMeasure(Metric):
 
     def __init__(
         self,
-        kernel_size: Sequence[int] = (11, 11),
-        sigma: Sequence[float] = (1.5, 1.5),
-        reduction: str = "elementwise_mean",
+        gaussian_kernel: bool = True,
+        sigma: Union[float, Sequence[float]] = 1.5,
+        kernel_size: Union[int, Sequence[int]] = 11,
+        reduction: Literal["elementwise_mean", "sum", "none", None] = "elementwise_mean",
         data_range: Optional[float] = None,
         k1: float = 0.01,
         k2: float = 0.03,
-        compute_on_step: bool = True,
-        dist_sync_on_step: bool = False,
-        process_group: Optional[Any] = None,
+        compute_on_step: Optional[bool] = None,
+        return_full_image: bool = False,
+        return_contrast_sensitivity: bool = False,
+        **kwargs: Dict[str, Any],
     ) -> None:
-        super().__init__(
-            compute_on_step=compute_on_step,
-            dist_sync_on_step=dist_sync_on_step,
-            process_group=process_group,
-        )
+        super().__init__(compute_on_step=compute_on_step, **kwargs)
         rank_zero_warn(
             "Metric `SSIM` will save all targets and"
             " predictions in buffer. For large datasets this may lead"
@@ -81,12 +95,15 @@ class StructuralSimilarityIndexMeasure(Metric):
 
         self.add_state("preds", default=[], dist_reduce_fx="cat")
         self.add_state("target", default=[], dist_reduce_fx="cat")
-        self.kernel_size = kernel_size
+        self.gaussian_kernel = gaussian_kernel
         self.sigma = sigma
+        self.kernel_size = kernel_size
+        self.reduction = reduction
         self.data_range = data_range
         self.k1 = k1
         self.k2 = k2
-        self.reduction = reduction
+        self.return_full_image = return_full_image
+        self.return_contrast_sensitivity = return_contrast_sensitivity
 
     def update(self, preds: Tensor, target: Tensor) -> None:  # type: ignore
         """Update state with predictions and targets.
@@ -104,52 +121,33 @@ class StructuralSimilarityIndexMeasure(Metric):
         preds = dim_zero_cat(self.preds)
         target = dim_zero_cat(self.target)
         return _ssim_compute(
-            preds, target, self.kernel_size, self.sigma, self.reduction, self.data_range, self.k1, self.k2
+            preds,
+            target,
+            self.gaussian_kernel,
+            self.sigma,
+            self.kernel_size,
+            self.reduction,
+            self.data_range,
+            self.k1,
+            self.k2,
+            self.return_full_image,
+            self.return_contrast_sensitivity,
         )
 
 
-class SSIM(StructuralSimilarityIndexMeasure):
-    """Computes Structual Similarity Index Measure (SSIM_).
-
-    .. deprecated:: v0.7
-        Use :class:`torchmetrics.StructuralSimilarityIndexMeasure`. Will be removed in v0.8.
-
-    Example:
-        >>> preds = torch.rand([16, 1, 16, 16])
-        >>> target = preds * 0.75
-        >>> ssim = SSIM()
-        >>> ssim(preds, target)
-        tensor(0.9219)
-    """
-
-    @deprecated(target=StructuralSimilarityIndexMeasure, deprecated_in="0.7", remove_in="0.8", stream=_future_warning)
-    def __init__(
-        self,
-        kernel_size: Sequence[int] = (11, 11),
-        sigma: Sequence[float] = (1.5, 1.5),
-        reduction: str = "elementwise_mean",
-        data_range: Optional[float] = None,
-        k1: float = 0.01,
-        k2: float = 0.03,
-        compute_on_step: bool = True,
-        dist_sync_on_step: bool = False,
-        process_group: Optional[Any] = None,
-    ) -> None:
-        void(kernel_size, sigma, reduction, data_range, k1, k2, compute_on_step, dist_sync_on_step, process_group)
-
-
 class MultiScaleStructuralSimilarityIndexMeasure(Metric):
     """Computes `MultiScaleSSIM`_, Multi-scale Structural Similarity Index Measure, which is a generalization of
     Structural Similarity Index Measure by incorporating image details at different resolution scores.
 
     Args:
+        gaussian_kernel: If ``True`` (default), a gaussian kernel is used, if false a uniform kernel is used
         kernel_size: size of the gaussian kernel
         sigma: Standard deviation of the gaussian kernel
         reduction: a method to reduce metric score over labels.
 
-            - ``'elementwise_mean'``: takes the mean (default)
+            - ``'elementwise_mean'``: takes the mean
             - ``'sum'``: takes the sum
-            - ``'none'``: no reduction will be applied
+            - ``'none'`` or ``None``: no reduction will be applied
 
         data_range: Range of the image. If ``None``, it is determined from the image (max - min)
         k1: Parameter of structural similarity index measure.
@@ -159,12 +157,28 @@ class MultiScaleStructuralSimilarityIndexMeasure(Metric):
         normalize: When MultiScaleStructuralSimilarityIndexMeasure loss is used for training, it is desirable to use
             normalizes to improve the training stability. This `normalize` argument is out of scope of the original
             implementation [1], and it is adapted from https://github.com/jorge-pessoa/pytorch-msssim instead.
+        compute_on_step:
+            Forward only calls ``update()`` and returns None if this is set to False.
+
+            .. deprecated:: v0.8
+                Argument has no use anymore and will be removed v0.9.
+
+        kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
     Return:
         Tensor with Multi-Scale SSIM score
 
+    Raises:
+        ValueError:
+            If ``kernel_size`` is not an int or a Sequence of ints with size 2 or 3.
+        ValueError:
+            If ``betas`` is not a tuple of floats with lengt 2.
+        ValueError:
+            If ``normalize`` is neither `None`, `ReLU` nor `simple`.
+
     Example:
         >>> from torchmetrics import MultiScaleStructuralSimilarityIndexMeasure
+        >>> import torch
         >>> preds = torch.rand([1, 1, 256, 256], generator=torch.manual_seed(42))
         >>> target = preds * 0.75
         >>> ms_ssim = MultiScaleStructuralSimilarityIndexMeasure()
@@ -172,8 +186,8 @@ class MultiScaleStructuralSimilarityIndexMeasure(Metric):
         tensor(0.9558)
 
     References:
-    [1] Multi-Scale Structural Similarity For Image Quality Assessment by Zhou Wang, Eero P. Simoncelli and Alan C.
-    Bovik `MultiScaleSSIM`_
+        [1] Multi-Scale Structural Similarity For Image Quality Assessment by Zhou Wang, Eero P. Simoncelli and Alan C.
+        Bovik `MultiScaleSSIM`_
     """
 
     preds: List[Tensor]
@@ -183,23 +197,19 @@ class MultiScaleStructuralSimilarityIndexMeasure(Metric):
 
     def __init__(
         self,
-        kernel_size: Sequence[int] = (11, 11),
-        sigma: Sequence[float] = (1.5, 1.5),
-        reduction: str = "elementwise_mean",
+        gaussian_kernel: bool = True,
+        kernel_size: Union[int, Sequence[int]] = 11,
+        sigma: Union[float, Sequence[float]] = 1.5,
+        reduction: Literal["elementwise_mean", "sum", "none", None] = "elementwise_mean",
         data_range: Optional[float] = None,
         k1: float = 0.01,
         k2: float = 0.03,
         betas: Tuple[float, ...] = (0.0448, 0.2856, 0.3001, 0.2363, 0.1333),
-        normalize: Optional[Literal["relu", "simple"]] = None,
-        compute_on_step: bool = True,
-        dist_sync_on_step: bool = False,
-        process_group: Optional[Any] = None,
+        normalize: Literal["relu", "simple", None] = None,
+        compute_on_step: Optional[bool] = None,
+        **kwargs: Dict[str, Any],
     ) -> None:
-        super().__init__(
-            compute_on_step=compute_on_step,
-            dist_sync_on_step=dist_sync_on_step,
-            process_group=process_group,
-        )
+        super().__init__(compute_on_step=compute_on_step, **kwargs)
         rank_zero_warn(
             "Metric `MS_SSIM` will save all targets and"
             " predictions in buffer. For large datasets this may lead"
@@ -209,18 +219,25 @@ class MultiScaleStructuralSimilarityIndexMeasure(Metric):
         self.add_state("preds", default=[], dist_reduce_fx="cat")
         self.add_state("target", default=[], dist_reduce_fx="cat")
 
-        all_kernel_ints = all(isinstance(ks, int) for ks in kernel_size)
-        if not isinstance(kernel_size, Sequence) or len(kernel_size) != 2 or not all_kernel_ints:
+        if not (isinstance(kernel_size, (Sequence, int))):
             raise ValueError(
-                "Argument `kernel_size` expected to be an sequence of size 2 where each element is an int"
-                f" but got {kernel_size}"
+                f"Argument `kernel_size` expected to be an sequence or an int, or a single int. Got {kernel_size}"
             )
-        self.kernel_size = kernel_size
+        if isinstance(kernel_size, Sequence) and (
+            len(kernel_size) not in (2, 3) or not all(isinstance(ks, int) for ks in kernel_size)
+        ):
+            raise ValueError(
+                "Argument `kernel_size` expected to be an sequence of size 2 or 3 where each element is an int, "
+                f"or a single int. Got {kernel_size}"
+            )
+
+        self.gaussian_kernel = gaussian_kernel
         self.sigma = sigma
+        self.kernel_size = kernel_size
+        self.reduction = reduction
         self.data_range = data_range
         self.k1 = k1
         self.k2 = k2
-        self.reduction = reduction
         if not isinstance(betas, tuple):
             raise ValueError("Argument `betas` is expected to be of a type tuple.")
         if isinstance(betas, tuple) and not all(isinstance(beta, float) for beta in betas):
@@ -234,8 +251,8 @@ class MultiScaleStructuralSimilarityIndexMeasure(Metric):
         """Update state with predictions and targets.
 
         Args:
-            preds: Predictions from model of shape `[N, C, H, W]`
-            target: Ground truth values of shape `[N, C, H, W]`
+            preds: Predictions from model of shape ``[N, C, H, W]``
+            target: Ground truth values of shape ``[N, C, H, W]``
         """
         preds, target = _ssim_update(preds, target)
         self.preds.append(preds)
@@ -248,8 +265,9 @@ class MultiScaleStructuralSimilarityIndexMeasure(Metric):
         return _multiscale_ssim_compute(
             preds,
             target,
-            self.kernel_size,
+            self.gaussian_kernel,
             self.sigma,
+            self.kernel_size,
             self.reduction,
             self.data_range,
             self.k1,
