@@ -15,12 +15,10 @@ from typing import Any, Callable, Dict, List, Optional, Union
 from warnings import warn
 
 import torch
-from deprecate import deprecated
 from torch import Tensor
 
 from torchmetrics.functional.text.bert import _preprocess_text, bert_score
 from torchmetrics.metric import Metric
-from torchmetrics.utilities import _future_warning
 from torchmetrics.utilities.imports import _TRANSFORMERS_AUTO_AVAILABLE
 
 if _TRANSFORMERS_AUTO_AVAILABLE:
@@ -48,19 +46,14 @@ class BERTScore(Metric):
     This implemenation follows the original implementation from `BERT_score`_.
 
     Args:
-        preds:
-            An iterable of predicted sentences.
-        target:
-            An iterable of target sentences.
-        model_type:
-            A name or a model path used to load `transformers` pretrained model.
-        num_layers:
-            A layer of representation to use.
+        preds: An iterable of predicted sentences.
+        target: An iterable of target sentences.
+        model_type: A name or a model path used to load `transformers` pretrained model.
+        num_layers: A layer of representation to use.
         all_layers:
             An indication of whether the representation from all model's layers should be used.
             If `all_layers = True`, the argument `num_layers` is ignored.
-        model:
-            A user's own model. Must be of `torch.nn.Module` instance.
+        model:  A user's own model. Must be of `torch.nn.Module` instance.
         user_tokenizer:
             A user's own tokenizer used with the own model. This must be an instance with the `__call__` method.
             This method must take an iterable of sentences (`List[str]`) and must return a python dictionary
@@ -72,42 +65,29 @@ class BERTScore(Metric):
             A user's own forward function used in a combination with `user_model`. This function must take `user_model`
             and a python dictionary of containing `"input_ids"` and `"attention_mask"` represented by `torch.Tensor`
             as an input and return the model's output represented by the single `torch.Tensor`.
-        verbose:
-            An indication of whether a progress bar to be displayed during the embeddings calculation.
-        idf:
-            An indication whether normalization using inverse document frequencies should be used.
-        device:
-            A device to be used for calculation.
-        max_length:
-            A maximum length of input sequences. Sequences longer than `max_length` are to be trimmed.
-        batch_size:
-            A batch size used for model processing.
-        num_threads:
-            A number of threads to use for a dataloader.
-        return_hash:
-            An indication of whether the correspodning `hash_code` should be returned.
-        lang:
-            A language of input sentences.
+        verbose: An indication of whether a progress bar to be displayed during the embeddings calculation.
+        idf: An indication whether normalization using inverse document frequencies should be used.
+        device: A device to be used for calculation.
+        max_length: A maximum length of input sequences. Sequences longer than `max_length` are to be trimmed.
+        batch_size: A batch size used for model processing.
+        num_threads: A number of threads to use for a dataloader.
+        return_hash: An indication of whether the correspodning `hash_code` should be returned.
+        lang: A language of input sentences.
         rescale_with_baseline:
             An indication of whether bertscore should be rescaled with a pre-computed baseline.
             When a pretrained model from `transformers` model is used, the corresponding baseline is downloaded
             from the original `bert-score` package from `BERT_score`_ if available.
             In other cases, please specify a path to the baseline csv/tsv file, which must follow the formatting
             of the files from `BERT_score`_.
-        baseline_path:
-            A path to the user's own local csv/tsv file with the baseline scale.
-        baseline_url:
-            A url path to the user's own  csv/tsv file with the baseline scale.
+        baseline_path: A path to the user's own local csv/tsv file with the baseline scale.
+        baseline_url: A url path to the user's own  csv/tsv file with the baseline scale.
         compute_on_step:
-            Forward only calls ``update()`` and return None if this is set to False.
-        dist_sync_on_step:
-            Synchronize metric state across processes at each ``forward()``
-            before returning the value at the step.
-        process_group:
-            Specify the process group on which synchronization is called.
-        dist_sync_fn:
-            Callback that performs the allgather operation on the metric state. When ``None``, DDP
-            will be used to perform the allgather
+            Forward only calls ``update()`` and returns None if this is set to False.
+
+            .. deprecated:: v0.8
+                Argument has no use anymore and will be removed v0.9.
+
+        kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
     Returns:
         Python dictionary containing the keys `precision`, `recall` and `f1` with corresponding values.
@@ -117,11 +97,11 @@ class BERTScore(Metric):
         >>> preds = ["hello there", "general kenobi"]
         >>> target = ["hello there", "master kenobi"]
         >>> bertscore = BERTScore()
+        >>> score = bertscore(preds, target)
         >>> from pprint import pprint
-        >>> pprint(bertscore(preds, target)) # doctest: +ELLIPSIS
-        {'f1': [0.999..., 0.996...],
-         'precision': [0.999..., 0.996...],
-         'recall': [0.999..., 0.996...]}
+        >>> rounded_score = {k: [round(v, 3) for v in vv] for k, vv in score.items()}
+        >>> pprint(rounded_score)
+        {'f1': [1.0, 0.996], 'precision': [1.0, 0.996], 'recall': [1.0, 0.996]}
     """
 
     is_differentiable = False
@@ -150,17 +130,10 @@ class BERTScore(Metric):
         rescale_with_baseline: bool = False,
         baseline_path: Optional[str] = None,
         baseline_url: Optional[str] = None,
-        compute_on_step: bool = True,
-        dist_sync_on_step: bool = False,
-        process_group: Optional[Any] = None,
-        dist_sync_fn: Callable = None,
+        compute_on_step: Optional[bool] = None,
+        **kwargs: Dict[str, Any],
     ):
-        super().__init__(
-            compute_on_step=compute_on_step,
-            dist_sync_on_step=dist_sync_on_step,
-            process_group=process_group,
-            dist_sync_fn=dist_sync_fn,
-        )
+        super().__init__(compute_on_step=compute_on_step, **kwargs)
         self.model_name_or_path = model_name_or_path or _DEFAULT_MODEL
         self.num_layers = num_layers
         self.all_layers = all_layers
@@ -203,29 +176,13 @@ class BERTScore(Metric):
         self.add_state("target_input_ids", [], dist_reduce_fx="cat")
         self.add_state("target_attention_mask", [], dist_reduce_fx="cat")
 
-    @deprecated(
-        args_mapping={"predictions": "preds", "references": "target"},
-        target=True,
-        deprecated_in="0.7",
-        remove_in="0.8",
-        stream=_future_warning,
-    )
     def update(self, preds: List[str], target: List[str]) -> None:  # type: ignore
         """Store predictions/references for computing BERT scores. It is necessary to store sentences in a
         tokenized form to ensure the DDP mode working.
 
         Args:
-            preds:
-                An iterable of predicted sentences.
-            target:
-                An iterable of reference sentences.
-
-        .. deprecated:: v0.7
-            Args:
-                predictions:
-                    This argument is deprecated in favor of  `preds` and will be removed in v0.8.
-                references:
-                    This argument is deprecated in favor of  `target` and will be removed in v0.8.
+            preds: An iterable of predicted sentences.
+            target: An iterable of reference sentences.
         """
         preds_dict = _preprocess_text(
             preds,
