@@ -29,29 +29,33 @@ __doctest_requires__ = {("ROUGEScore",): ["nltk"]}
 
 
 class ROUGEScore(Metric):
-    """`Calculate Rouge Score`_, used for automatic summarization. This implementation should imitate the behaviour
-    of the `rouge-score` package `Python ROUGE Implementation`
+    """`Calculate Rouge Score`_, used for automatic summarization.
+
+    This implementation should imitate the behaviour of the `rouge-score` package `Python ROUGE Implementation`
 
     Args:
-        use_stemmer:
-            Use Porter stemmer to strip word suffixes to improve matching.
+        use_stemmer: Use Porter stemmer to strip word suffixes to improve matching.
+        normalizer: A user's own normalizer function.
+            If this is ``None``, replacing any non-alpha-numeric characters with spaces is default.
+            This function must take a ``str`` and return a ``str``.
+        tokenizer:
+            A user's own tokenizer function. If this is ``None``, spliting by spaces is default
+            This function must take a `str` and return ``Sequence[str]``
         accumulate:
-            Useful incase of multi-reference rouge score.
+            Useful in case of multi-reference rouge score.
+
             - ``avg`` takes the avg of all references with respect to predictions
             - ``best`` takes the best fmeasure score obtained between prediction and multiple corresponding references.
-        rouge_keys:
-            A list of rouge types to calculate.
+
+        rouge_keys: A list of rouge types to calculate.
             Keys that are allowed are ``rougeL``, ``rougeLsum``, and ``rouge1`` through ``rouge9``.
         compute_on_step:
             Forward only calls ``update()`` and returns None if this is set to False.
-        dist_sync_on_step:
-            Synchronize metric state across processes at each ``forward()``
-            before returning the value at the step.
-        process_group:
-            Specify the process group on which synchronization is called.
-        dist_sync_fn:
-            Callback that performs the allgather operation on the metric state. When `None`, DDP
-            will be used to perform the allgather.
+
+            .. deprecated:: v0.8
+                Argument has no use anymore and will be removed v0.9.
+
+        kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
     Example:
         >>> from torchmetrics.text.rouge import ROUGEScore
@@ -89,19 +93,14 @@ class ROUGEScore(Metric):
     def __init__(
         self,
         use_stemmer: bool = False,
+        normalizer: Callable[[str], str] = None,
+        tokenizer: Callable[[str], Sequence[str]] = None,
         accumulate: Literal["avg", "best"] = "best",
         rouge_keys: Union[str, Tuple[str, ...]] = ("rouge1", "rouge2", "rougeL", "rougeLsum"),  # type: ignore
-        compute_on_step: bool = True,
-        dist_sync_on_step: bool = False,
-        process_group: Optional[Any] = None,
-        dist_sync_fn: Optional[Callable] = None,
+        compute_on_step: Optional[bool] = None,
+        **kwargs: Dict[str, Any],
     ):
-        super().__init__(
-            compute_on_step=compute_on_step,
-            dist_sync_on_step=dist_sync_on_step,
-            process_group=process_group,
-            dist_sync_fn=dist_sync_fn,
-        )
+        super().__init__(compute_on_step=compute_on_step, **kwargs)
         if use_stemmer or "rougeLsum" in rouge_keys:
             if not _NLTK_AVAILABLE:
                 raise ModuleNotFoundError(
@@ -110,7 +109,7 @@ class ROUGEScore(Metric):
             import nltk
 
         if not isinstance(rouge_keys, tuple):
-            rouge_keys = tuple([rouge_keys])
+            rouge_keys = (rouge_keys,)
         for key in rouge_keys:
             if key not in ALLOWED_ROUGE_KEYS:
                 raise ValueError(f"Got unknown rouge key {key}. Expected to be one of {ALLOWED_ROUGE_KEYS}")
@@ -123,6 +122,8 @@ class ROUGEScore(Metric):
         self.rouge_keys = rouge_keys
         self.rouge_keys_values = [ALLOWED_ROUGE_KEYS[key] for key in rouge_keys]
         self.stemmer = nltk.stem.porter.PorterStemmer() if use_stemmer else None
+        self.normalizer = normalizer
+        self.tokenizer = tokenizer
         self.accumulate = accumulate
 
         # Adding stated dynamically to prevent IndexError during sync function as some lists can be empty.
@@ -136,11 +137,8 @@ class ROUGEScore(Metric):
         """Compute rouge scores.
 
         Args:
-            preds:
-                An iterable of predicted sentences or a single predicted sentence.
-            target:
-                An iterable of iterable of target sentences or an iterable
-                of target sentences or a single target sentence.
+            preds: An iterable of predicted sentences or a single predicted sentence.
+            target: An iterable of target sentences or an iterable of target sentences or a single target sentence.
         """
         if isinstance(target, list) and all(isinstance(tgt, str) for tgt in target):
             target = [target] if isinstance(preds, str) else [[tgt] for tgt in target]
@@ -152,12 +150,18 @@ class ROUGEScore(Metric):
             target = [[target]]
 
         output: Dict[Union[int, str], List[Dict[str, Tensor]]] = _rouge_score_update(
-            preds, target, self.rouge_keys_values, stemmer=self.stemmer, accumulate=self.accumulate
+            preds,
+            target,
+            self.rouge_keys_values,
+            stemmer=self.stemmer,
+            normalizer=self.normalizer,
+            tokenizer=self.tokenizer,
+            accumulate=self.accumulate,
         )
         for rouge_key, metrics in output.items():
             for metric in metrics:
-                for type, value in metric.items():
-                    getattr(self, f"rouge{rouge_key}_{type}").append(value.to(self.device))
+                for tp, value in metric.items():
+                    getattr(self, f"rouge{rouge_key}_{tp}").append(value.to(self.device))
 
     def compute(self) -> Dict[str, Tensor]:
         """Calculate (Aggregate and provide confidence intervals) ROUGE score.
@@ -167,8 +171,8 @@ class ROUGEScore(Metric):
         """
         update_output = {}
         for rouge_key in self.rouge_keys_values:
-            for type in ["fmeasure", "precision", "recall"]:
-                update_output[f"rouge{rouge_key}_{type}"] = getattr(self, f"rouge{rouge_key}_{type}")
+            for tp in ["fmeasure", "precision", "recall"]:
+                update_output[f"rouge{rouge_key}_{tp}"] = getattr(self, f"rouge{rouge_key}_{tp}")
 
         return _rouge_score_compute(update_output)
 
