@@ -17,16 +17,13 @@
 # Authors: torchtext authors and @sluks
 # Date: 2020-07-18
 # Link: https://pytorch.org/text/_modules/torchtext/data/metrics.html#bleu_score
-from typing import Any, Callable, Optional, Sequence
-from warnings import warn
+from typing import Any, Dict, Optional, Sequence
 
-from deprecate import deprecated
 from typing_extensions import Literal
 
 from torchmetrics.functional.text.bleu import _bleu_score_update
 from torchmetrics.functional.text.sacre_bleu import _SacreBLEUTokenizer
 from torchmetrics.text.bleu import BLEUScore
-from torchmetrics.utilities import _future_warning
 from torchmetrics.utilities.imports import _REGEX_AVAILABLE
 
 AVAILABLE_TOKENIZERS = ("none", "13a", "zh", "intl", "char")
@@ -39,25 +36,18 @@ class SacreBLEUScore(BLEUScore):
     The SacreBLEU implementation differs from the NLTK BLEU implementation in tokenization techniques.
 
     Args:
-        n_gram:
-            Gram value ranged from 1 to 4 (Default 4)
-        smooth:
-            Whether or not to apply smoothing – see [2]
-        tokenize:
-            Tokenization technique to be used. (Default '13a')
-            Supported tokenization: ['none', '13a', 'zh', 'intl', 'char']
-        lowercase:
-            If ``True``, BLEU score over lowercased text is calculated.
+        n_gram: Gram value ranged from 1 to 4 (Default 4)
+        smooth: Whether to apply smoothing, see [2]
+        tokenize: Tokenization technique to be used.
+            Supported tokenization: ``['none', '13a', 'zh', 'intl', 'char']``
+        lowercase:  If ``True``, BLEU score over lowercased text is calculated.
         compute_on_step:
             Forward only calls ``update()`` and returns None if this is set to False.
-        dist_sync_on_step:
-            Synchronize metric state across processes at each ``forward()``
-            before returning the value at the step.
-        process_group:
-            Specify the process group on which synchronization is called.
-        dist_sync_fn:
-            Callback that performs the allgather operation on the metric state. When `None`, DDP
-            will be used to perform the allgather.
+
+            .. deprecated:: v0.8
+                Argument has no use anymore and will be removed v0.9.
+
+        kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
      Raises:
         ValueError:
@@ -90,23 +80,10 @@ class SacreBLEUScore(BLEUScore):
         smooth: bool = False,
         tokenize: Literal["none", "13a", "zh", "intl", "char"] = "13a",
         lowercase: bool = False,
-        compute_on_step: bool = True,
-        dist_sync_on_step: bool = False,
-        process_group: Optional[Any] = None,
-        dist_sync_fn: Optional[Callable] = None,
+        compute_on_step: Optional[bool] = None,
+        **kwargs: Dict[str, Any],
     ):
-        super().__init__(
-            n_gram=n_gram,
-            smooth=smooth,
-            compute_on_step=compute_on_step,
-            dist_sync_on_step=dist_sync_on_step,
-            process_group=process_group,
-            dist_sync_fn=dist_sync_fn,
-        )
-        warn(
-            "Input order of targets and preds were changed to predictions firsts and targets \
-                    second in v0.7. Warning will be removed in v0.8"
-        )
+        super().__init__(n_gram=n_gram, smooth=smooth, compute_on_step=compute_on_step, **kwargs)
         if tokenize not in AVAILABLE_TOKENIZERS:
             raise ValueError(f"Argument `tokenize` expected to be one of {AVAILABLE_TOKENIZERS} but got {tokenize}.")
 
@@ -117,26 +94,12 @@ class SacreBLEUScore(BLEUScore):
             )
         self.tokenizer = _SacreBLEUTokenizer(tokenize, lowercase)
 
-    @deprecated(
-        args_mapping={"translate_corpus": "preds", "reference_corpus": "target"},
-        target=True,
-        deprecated_in="0.7",
-        remove_in="0.8",
-        stream=_future_warning,
-    )
     def update(self, preds: Sequence[str], target: Sequence[Sequence[str]]) -> None:  # type: ignore
         """Compute Precision Scores.
 
         Args:
             preds: An iterable of machine translated corpus
             target: An iterable of iterables of reference corpus
-
-        .. deprecated:: v0.7
-            Args:
-                translate_corpus:
-                    This argument is deprecated in favor of  `preds` and will be removed in v0.8.
-                reference_corpus:
-                    This argument is deprecated in favor of  `target` and will be removed in v0.8.
         """
         self.preds_len, self.target_len = _bleu_score_update(
             preds,
