@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import Any, Callable, List, Optional, Union
+from typing import Any, Dict, List, Optional, Union
 
 from torch import Tensor, tensor
 
@@ -21,8 +21,7 @@ from torchmetrics.metric import Metric
 
 
 class WordInfoLost(Metric):
-    r"""
-    Word Information Lost (WordInfoLost_) is a metric of the performance of an automatic speech
+    r"""Word Information Lost (WIL_) is a metric of the performance of an automatic speech
     recognition system. This value indicates the percentage of words that were incorrectly predicted
     between a set of ground-truth sentences and a set of hypothesis sentences.
     The lower the value, the better the performance of the ASR system with a WordInfoLost of
@@ -34,22 +33,19 @@ class WordInfoLost(Metric):
 
     where:
 
-        - C is the number of correct words,
-        - N is the number of words in the reference
-        - P is the number of words in the prediction
+        - :math:`C` is the number of correct words,
+        - :math:`N` is the number of words in the reference
+        - :math:`P` is the number of words in the prediction
 
 
     Args:
         compute_on_step:
-            Forward only calls ``update()`` and return None if this is set to False.
-        dist_sync_on_step:
-            Synchronize metric state across processes at each ``forward()``
-            before returning the value at the step.
-        process_group:
-            Specify the process group on which synchronization is called.
-        dist_sync_fn:
-            Callback that performs the allgather operation on the metric state. When ``None``, DDP
-            will be used to perform the allgather
+            Forward only calls ``update()`` and returns None if this is set to False.
+
+            .. deprecated:: v0.8
+                Argument has no use anymore and will be removed v0.9.
+
+        kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
 
     Examples:
@@ -68,17 +64,10 @@ class WordInfoLost(Metric):
 
     def __init__(
         self,
-        compute_on_step: bool = True,
-        dist_sync_on_step: bool = False,
-        process_group: Optional[Any] = None,
-        dist_sync_fn: Callable = None,
+        compute_on_step: Optional[bool] = None,
+        **kwargs: Dict[str, Any],
     ):
-        super().__init__(
-            compute_on_step=compute_on_step,
-            dist_sync_on_step=dist_sync_on_step,
-            process_group=process_group,
-            dist_sync_fn=dist_sync_fn,
-        )
+        super().__init__(compute_on_step=compute_on_step, **kwargs)
         self.add_state("errors", tensor(0.0), dist_reduce_fx="sum")
         self.add_state("target_total", tensor(0.0), dist_reduce_fx="sum")
         self.add_state("preds_total", tensor(0.0), dist_reduce_fx="sum")
@@ -87,10 +76,8 @@ class WordInfoLost(Metric):
         """Store predictions/references for computing Word Information Lost scores.
 
         Args:
-            preds:
-                Transcription(s) to score as a string or list of strings
-            target:
-                Reference(s) for each speech input as a string or list of strings
+            preds: Transcription(s) to score as a string or list of strings
+            target: Reference(s) for each speech input as a string or list of strings
         """
         errors, target_total, preds_total = _wil_update(preds, target)
         self.errors += errors
