@@ -20,18 +20,32 @@ from torchmetrics.utilities.data import select_topk, to_onehot
 from torchmetrics.utilities.enums import DataType
 
 
+def _check_for_empty_tensors(preds: Tensor, target: Tensor) -> bool:
+    if preds.numel() == target.numel() == 0:
+        return True
+    return False
+
+
 def _check_same_shape(preds: Tensor, target: Tensor) -> None:
     """Check that predictions and target have the same shape, else raise error."""
     if preds.shape != target.shape:
         raise RuntimeError("Predictions and targets are expected to have the same shape")
 
 
-def _basic_input_validation(preds: Tensor, target: Tensor, threshold: float, multiclass: Optional[bool]) -> None:
+def _basic_input_validation(
+    preds: Tensor, target: Tensor, threshold: float, multiclass: Optional[bool], ignore_index: Optional[int]
+) -> None:
     """Perform basic validation of inputs that does not require deducing any information of the type of inputs."""
+    # Skip all other checks if both preds and target are empty tensors
+    if _check_for_empty_tensors(preds, target):
+        return
 
     if target.is_floating_point():
         raise ValueError("The `target` has to be an integer tensor.")
-    if target.min() < 0:
+
+    if ignore_index is None and target.min() < 0:
+        raise ValueError("The `target` has to be a non-negative tensor.")
+    elif ignore_index is not None and ignore_index >= 0 and target.min() < 0:
         raise ValueError("The `target` has to be a non-negative tensor.")
 
     preds_float = preds.is_floating_point()
@@ -65,7 +79,7 @@ def _check_shape_and_type_consistency(preds: Tensor, target: Tensor) -> Tuple[Da
                 "The `preds` and `target` should have the same shape,",
                 f" got `preds` with shape={preds.shape} and `target` with shape={target.shape}.",
             )
-        if preds_float and target.max() > 1:
+        if preds_float and target.numel() > 0 and target.max() > 1:
             raise ValueError(
                 "If `preds` and `target` are of shape (N, ...) and `preds` are floats, `target` should be binary."
             )
@@ -79,8 +93,7 @@ def _check_shape_and_type_consistency(preds: Tensor, target: Tensor) -> Tuple[Da
             case = DataType.MULTILABEL
         else:
             case = DataType.MULTIDIM_MULTICLASS
-
-        implied_classes = preds[0].numel()
+        implied_classes = preds[0].numel() if preds.numel() > 0 else 0
 
     elif preds.ndim == target.ndim + 1:
         if not preds_float:
@@ -91,7 +104,7 @@ def _check_shape_and_type_consistency(preds: Tensor, target: Tensor) -> Tuple[Da
                 " (N, C, ...), and the shape of `target` should be (N, ...)."
             )
 
-        implied_classes = preds.shape[1]
+        implied_classes = preds.shape[1] if preds.numel() > 0 else 0
 
         if preds.ndim == 2:
             case = DataType.MULTICLASS
@@ -149,14 +162,14 @@ def _check_num_classes_mc(
                 " should be either None or the product of the size of extra dimensions (...)."
                 " See Input Types in Metrics documentation."
             )
-        if num_classes <= target.max():
+        if target.numel() > 0 and num_classes <= target.max():
             raise ValueError("The highest label in `target` should be smaller than `num_classes`.")
         if preds.shape != target.shape and num_classes != implied_classes:
             raise ValueError("The size of C dimension of `preds` does not match `num_classes`.")
 
 
 def _check_num_classes_ml(num_classes: int, multiclass: Optional[bool], implied_classes: int) -> None:
-    """This checks that the consistency of `num_classes` with the data and `multiclass` param for multi-label
+    """This checks that the consistency of ``num_classes`` with the data and ``multiclass`` param for multi-label
     data."""
 
     if multiclass and num_classes != 2:
@@ -194,6 +207,7 @@ def _check_classification_inputs(
     num_classes: Optional[int],
     multiclass: Optional[bool],
     top_k: Optional[int],
+    ignore_index: Optional[int] = None,
 ) -> DataType:
     """Performs error checking on inputs for classification.
 
@@ -202,7 +216,7 @@ def _check_classification_inputs(
     over-rides with ``multiclass`` by checking (for multi-class and multi-dim multi-class
     cases) that there are only up to 2 distinct labels.
 
-    In case where preds are floats (probabilities), it is checked whether they are in [0,1] interval.
+    In case where preds are floats (probabilities), it is checked whether they are in ``[0,1]`` interval.
 
     When ``num_classes`` is given, it is checked that it is consistent with input cases (binary,
     multi-label, ...), and that, if available, the implied number of classes in the ``C``
@@ -212,7 +226,7 @@ def _check_classification_inputs(
     value against ``C`` dimension is checked for (multi-dimensional) multi-class cases.
 
     If ``top_k`` is set (not None) for inputs that do not have probability predictions (and
-    are not binary), an error is raised. Similarly if ``top_k`` is set to a number that
+    are not binary), an error is raised. Similarly, if ``top_k`` is set to a number that
     is higher than or equal to the ``C`` dimension of ``preds``, an error is raised.
 
     Preds and target tensors are expected to be squeezed already - all dimensions should be
@@ -248,7 +262,7 @@ def _check_classification_inputs(
     """
 
     # Basic validation (that does not need case/type information)
-    _basic_input_validation(preds, target, threshold, multiclass)
+    _basic_input_validation(preds, target, threshold, multiclass, ignore_index)
 
     # Check that shape/types fall into one of the cases
     case, implied_classes = _check_shape_and_type_consistency(preds, target)
@@ -300,6 +314,7 @@ def _input_format_classification(
     top_k: Optional[int] = None,
     num_classes: Optional[int] = None,
     multiclass: Optional[bool] = None,
+    ignore_index: Optional[int] = None,
 ) -> Tuple[Tensor, Tensor, DataType]:
     """Convert preds and target tensors into common format.
 
@@ -338,7 +353,7 @@ def _input_format_classification(
 
     In multi-label case, normally targets and preds are returned as ``(N, C)`` binary tensors, with
     preds being binarized as in the binary case. Here the ``C`` dimension is obtained by flattening
-    all dimensions after the first one. However if ``multiclass=True``, then both are returned as
+    all dimensions after the first one. However, if ``multiclass=True``, then both are returned as
     ``(N, 2, C)``, by an equivalent transformation as in the binary case.
 
     In multi-dimensional multi-class case, normally both target and preds are returned as
@@ -364,9 +379,9 @@ def _input_format_classification(
             either from the shape of inputs, or the maximum label in the ``target`` and ``preds``
             tensor, where applicable.
         top_k:
-            Number of highest probability entries for each sample to convert to 1s - relevant
+            Number of the highest probability entries for each sample to convert to 1s - relevant
             only for (multi-dimensional) multi-class inputs with probability predictions. The
-            default value (``None``) will be interepreted as 1 for these inputs.
+            default value (``None``) will be interpreted as 1 for these inputs.
 
             Should be left unset (``None``) for all other types of inputs.
         multiclass:
@@ -396,6 +411,7 @@ def _input_format_classification(
         num_classes=num_classes,
         multiclass=multiclass,
         top_k=top_k,
+        ignore_index=ignore_index,
     )
 
     if case in (DataType.BINARY, DataType.MULTILABEL) and not top_k:
@@ -418,12 +434,13 @@ def _input_format_classification(
         if multiclass is False:
             preds, target = preds[:, 1, ...], target[:, 1, ...]
 
-    if (case in (DataType.MULTICLASS, DataType.MULTIDIM_MULTICLASS) and multiclass is not False) or multiclass:
-        target = target.reshape(target.shape[0], target.shape[1], -1)
-        preds = preds.reshape(preds.shape[0], preds.shape[1], -1)
-    else:
-        target = target.reshape(target.shape[0], -1)
-        preds = preds.reshape(preds.shape[0], -1)
+    if not _check_for_empty_tensors(preds, target):
+        if (case in (DataType.MULTICLASS, DataType.MULTIDIM_MULTICLASS) and multiclass is not False) or multiclass:
+            target = target.reshape(target.shape[0], target.shape[1], -1)
+            preds = preds.reshape(preds.shape[0], preds.shape[1], -1)
+        else:
+            target = target.reshape(target.shape[0], -1)
+            preds = preds.reshape(preds.shape[0], -1)
 
     # Some operations above create an extra dimension for MC/binary case - this removes it
     if preds.ndim > 2:
@@ -516,6 +533,7 @@ def _check_retrieval_inputs(
     preds: Tensor,
     target: Tensor,
     allow_non_binary_target: bool = False,
+    ignore_index: Optional[int] = None,
 ) -> Tuple[Tensor, Tensor, Tensor]:
     """Check ``indexes``, ``preds`` and ``target`` tensors are of the same shape and of the correct dtype.
 
@@ -523,28 +541,33 @@ def _check_retrieval_inputs(
         indexes: tensor with queries indexes
         preds: tensor with scores/logits
         target: tensor with ground true labels
+        ignore_index: ignore predictions where targets are equal to this number
 
     Raises:
         ValueError:
-            If ``preds`` and ``target`` don't have the same shape, if they are empty
-            or not of the correct ``dtypes``.
+            If ``preds`` and ``target`` don't have the same shape, if they are empty or not of the correct ``dtypes``.
 
     Returns:
-        indexes: as torch.long
-        preds: as torch.float32
-        target: as torch.long
+        indexes: as ``torch.long``
+        preds: as ``torch.float32``
+        target: as ``torch.long``
     """
     if indexes.shape != preds.shape or preds.shape != target.shape:
         raise ValueError("`indexes`, `preds` and `target` must be of the same shape")
 
+    if indexes.dtype is not torch.long:
+        raise ValueError("`indexes` must be a tensor of long integers")
+
+    # remove predictions where target is equal to `ignore_index`
+    if ignore_index is not None:
+        valid_positions = target != ignore_index
+        indexes, preds, target = indexes[valid_positions], preds[valid_positions], target[valid_positions]
+
     if not indexes.numel() or not indexes.size():
         raise ValueError(
             "`indexes`, `preds` and `target` must be non-empty and non-scalar tensors",
         )
 
-    if indexes.dtype is not torch.long:
-        raise ValueError("`indexes` must be a tensor of long integers")
-
     preds, target = _check_retrieval_target_and_prediction_types(
         preds, target, allow_non_binary_target=allow_non_binary_target
     )
@@ -566,8 +589,7 @@ def _check_retrieval_target_and_prediction_types(
 
     Raises:
         ValueError:
-            If ``preds`` and ``target`` don't have the same shape, if they are empty
-            or not of the correct ``dtypes``.
+            If ``preds`` and ``target`` don't have the same shape, if they are empty or not of the correct ``dtypes``.
     """
     if target.dtype not in (torch.bool, torch.long, torch.int) and not torch.is_floating_point(target):
         raise ValueError("`target` must be a tensor of booleans, integers or floats")
@@ -578,5 +600,7 @@ def _check_retrieval_target_and_prediction_types(
     if not allow_non_binary_target and (target.max() > 1 or target.min() < 0):
         raise ValueError("`target` must contain `binary` values")
 
-    target = target.float().flatten() if target.is_floating_point() else target.long().flatten()
-    return preds.float().flatten(), target
+    target = target.float() if target.is_floating_point() else target.long()
+    preds = preds.float()
+
+    return preds.flatten(), target.flatten()
