@@ -11,18 +11,16 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Any, Callable, List, Mapping, Optional, Sequence, Union
+from typing import Any, Callable, Dict, List, Mapping, Optional, Sequence, Union
 
 import torch
 from torch import Tensor, tensor
 
-from torchmetrics.utilities.prints import rank_zero_warn
-
 METRIC_EPS = 1e-6
 
 
 def dim_zero_cat(x: Union[Tensor, List[Tensor]]) -> Tensor:
-    """concatenation along the zero dimension."""
+    """Concatenation along the zero dimension."""
     x = x if isinstance(x, (list, tuple)) else [x]
     x = [y.unsqueeze(0) if y.numel() == 1 and y.ndim == 0 else y for y in x]
     if not x:  # empty list
@@ -31,29 +29,42 @@ def dim_zero_cat(x: Union[Tensor, List[Tensor]]) -> Tensor:
 
 
 def dim_zero_sum(x: Tensor) -> Tensor:
-    """summation along the zero dimension."""
+    """Summation along the zero dimension."""
     return torch.sum(x, dim=0)
 
 
 def dim_zero_mean(x: Tensor) -> Tensor:
-    """average along the zero dimension."""
+    """Average along the zero dimension."""
     return torch.mean(x, dim=0)
 
 
 def dim_zero_max(x: Tensor) -> Tensor:
-    """max along the zero dimension."""
+    """Max along the zero dimension."""
     return torch.max(x, dim=0).values
 
 
 def dim_zero_min(x: Tensor) -> Tensor:
-    """min along the zero dimension."""
+    """Min along the zero dimension."""
     return torch.min(x, dim=0).values
 
 
 def _flatten(x: Sequence) -> list:
+    """Flatten list of list into single list."""
     return [item for sublist in x for item in sublist]
 
 
+def _flatten_dict(x: Dict) -> Dict:
+    """Flatten dict of dicts into single dict."""
+    new_dict = {}
+    for key, value in x.items():
+        if isinstance(value, dict):
+            for k, v in value.items():
+                new_dict[k] = v
+        else:
+            new_dict[key] = value
+    return new_dict
+
+
 def to_onehot(
     label_tensor: Tensor,
     num_classes: Optional[int] = None,
@@ -89,16 +100,16 @@ def to_onehot(
 
 
 def select_topk(prob_tensor: Tensor, topk: int = 1, dim: int = 1) -> Tensor:
-    """Convert a probability tensor to binary by selecting top-k highest entries.
+    """Convert a probability tensor to binary by selecting top-k the highest entries.
 
     Args:
         prob_tensor: dense tensor of shape ``[..., C, ...]``, where ``C`` is in the
             position defined by the ``dim`` argument
-        topk: number of highest entries to turn into 1s
+        topk: number of the highest entries to turn into 1s
         dim: dimension on which to compare entries
 
     Returns:
-        A binary tensor of the same shape as the input tensor of type torch.int32
+        A binary tensor of the same shape as the input tensor of type ``torch.int32``
 
     Example:
         >>> x = torch.tensor([[1.1, 2.0, 3.0], [2.0, 1.0, 0.5]])
@@ -132,37 +143,6 @@ def to_categorical(x: Tensor, argmax_dim: int = 1) -> Tensor:
     return torch.argmax(x, dim=argmax_dim)
 
 
-def get_num_classes(
-    preds: Tensor,
-    target: Tensor,
-    num_classes: Optional[int] = None,
-) -> int:
-    """Calculates the number of classes for a given prediction and target tensor.
-
-    Args:
-        preds: predicted values
-        target: true labels
-        num_classes: number of classes if known
-
-    Return:
-        An integer that represents the number of classes.
-    """
-    num_target_classes = int(target.max().detach().item() + 1)
-    num_pred_classes = int(preds.max().detach().item() + 1)
-    num_all_classes = max(num_target_classes, num_pred_classes)
-
-    if num_classes is None:
-        num_classes = num_all_classes
-    elif num_classes != num_all_classes:
-        rank_zero_warn(
-            f"You have set {num_classes} number of classes which is"
-            f" different from predicted ({num_pred_classes}) and"
-            f" target ({num_target_classes}) number of classes",
-            RuntimeWarning,
-        )
-    return num_classes
-
-
 def apply_to_collection(
     data: Any,
     dtype: Union[type, tuple],
@@ -214,14 +194,14 @@ def apply_to_collection(
 
 
 def get_group_indexes(indexes: Tensor) -> List[Tensor]:
-    """Given an integer `torch.Tensor` `indexes`, return a `torch.Tensor` of indexes for each different value in
-    `indexes`.
+    """Given an integer ``torch.Tensor`` ``indexes``, return a ``torch.Tensor`` of indexes for each different value
+    in ``indexes``.
 
     Args:
-        indexes: a `torch.Tensor`
+        indexes: a ``torch.Tensor``
 
     Return:
-        A list of integer `torch.Tensor`s
+        A list of integer ``torch.Tensor``s
 
     Example:
         >>> indexes = torch.tensor([0, 0, 0, 1, 1, 1, 1])
@@ -249,15 +229,16 @@ def _squeeze_if_scalar(data: Any) -> Any:
 
 
 def _bincount(x: Tensor, minlength: Optional[int] = None) -> Tensor:
-    """torch.bincount currently does not support deterministic mode on GPU. This implementation fallsback to a for-
-    loop counting occurences in that case.
+    """``torch.bincount`` currently does not support deterministic mode on GPU.
+
+    This implementation fallback to a for-loop counting occurrences in that case.
 
     Args:
         x: tensor to count
         minlength: minimum length to count
 
     Returns:
-        Number of occurences for each unique element in x
+        Number of occurrences for each unique element in x
     """
     if x.is_cuda and torch.are_deterministic_algorithms_enabled():
         if minlength is None:
