@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 from copy import deepcopy
-from typing import Any, Callable, Dict, Optional, Union
+from typing import Any, Dict, Optional, Union
 
 import torch
 from torch import Tensor, nn
@@ -26,15 +26,14 @@ def _bootstrap_sampler(
     size: int,
     sampling_strategy: str = "poisson",
 ) -> Tensor:
-    """Resample a tensor along its first dimension with replacement
+    """Resample a tensor along its first dimension with replacement.
+
     Args:
         size: number of samples
         sampling_strategy: the strategy to use for sampling, either ``'poisson'`` or ``'multinomial'``
-        generator: a instance of ``torch.Generator`` that controls the sampling
 
     Returns:
         resampled tensor
-
     """
     if sampling_strategy == "poisson":
         p = torch.distributions.Poisson(1)
@@ -47,6 +46,47 @@ def _bootstrap_sampler(
 
 
 class BootStrapper(Metric):
+    r"""
+    Using `Turn a Metric into a Bootstrapped`_
+
+    That can automate the process of getting confidence intervals for metric values. This wrapper
+    class basically keeps multiple copies of the same base metric in memory and whenever ``update`` or
+    ``forward`` is called, all input tensors are resampled (with replacement) along the first dimension.
+
+    Args:
+        base_metric: base metric class to wrap
+        num_bootstraps: number of copies to make of the base metric for bootstrapping
+        mean: if ``True`` return the mean of the bootstraps
+        std: if ``True`` return the standard diviation of the bootstraps
+        quantile: if given, returns the quantile of the bootstraps. Can only be used with pytorch version 1.6 or higher
+        raw: if ``True``, return all bootstrapped values
+        sampling_strategy:
+            Determines how to produce bootstrapped samplings. Either ``'poisson'`` or ``multinomial``.
+            If ``'possion'`` is chosen, the number of times each sample will be included in the bootstrap
+            will be given by :math:`n\sim Poisson(\lambda=1)`, which approximates the true bootstrap distribution
+            when the number of samples is large. If ``'multinomial'`` is chosen, we will apply true bootstrapping
+            at the batch level to approximate bootstrapping over the hole dataset.
+        compute_on_step:
+            Forward only calls ``update()`` and returns None if this is set to False.
+
+            .. deprecated:: v0.8
+                Argument has no use anymore and will be removed v0.9.
+
+        kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
+
+    Example::
+        >>> from pprint import pprint
+        >>> from torchmetrics import Accuracy, BootStrapper
+        >>> _ = torch.manual_seed(123)
+        >>> base_metric = Accuracy()
+        >>> bootstrap = BootStrapper(base_metric, num_bootstraps=20)
+        >>> bootstrap.update(torch.randint(5, (20,)), torch.randint(5, (20,)))
+        >>> output = bootstrap.compute()
+        >>> pprint(output)
+        {'mean': tensor(0.2205), 'std': tensor(0.0859)}
+
+    """
+
     def __init__(
         self,
         base_metric: Metric,
@@ -56,62 +96,10 @@ class BootStrapper(Metric):
         quantile: Optional[Union[float, Tensor]] = None,
         raw: bool = False,
         sampling_strategy: str = "poisson",
-        compute_on_step: bool = True,
-        dist_sync_on_step: bool = False,
-        process_group: Optional[Any] = None,
-        dist_sync_fn: Callable = None,
+        compute_on_step: Optional[bool] = None,
+        **kwargs: Dict[str, Any],
     ) -> None:
-        r"""
-        Use to turn a metric into a `bootstrapped <https://en.wikipedia.org/wiki/Bootstrapping_(statistics)>`_
-        metric that can automate the process of getting confidence intervals for metric values. This wrapper
-        class basically keeps multiple copies of the same base metric in memory and whenever ``update`` or
-        ``forward`` is called, all input tensors are resampled (with replacement) along the first dimension.
-
-        Args:
-            base_metric:
-                base metric class to wrap
-            num_bootstraps:
-                number of copies to make of the base metric for bootstrapping
-            mean:
-                if ``True`` return the mean of the bootstraps
-            std:
-                if ``True`` return the standard diviation of the bootstraps
-            quantile:
-                if given, returns the quantile of the bootstraps. Can only be used with
-                pytorch version 1.6 or higher
-            raw:
-                if ``True``, return all bootstrapped values
-            sampling_strategy:
-                Determines how to produce bootstrapped samplings. Either ``'poisson'`` or ``multinomial``.
-                If ``'possion'`` is chosen, the number of times each sample will be included in the bootstrap
-                will be given by :math:`n\sim Poisson(\lambda=1)`, which approximates the true bootstrap distribution
-                when the number of samples is large. If ``'multinomial'`` is chosen, we will apply true bootstrapping
-                at the batch level to approximate bootstrapping over the hole dataset.
-            compute_on_step:
-                Forward only calls ``update()`` and return ``None`` if this is set to ``False``.
-            dist_sync_on_step:
-                Synchronize metric state across processes at each ``forward()``
-                before returning the value at the step
-            process_group:
-                Specify the process group on which synchronization is called.
-                default: ``None`` (which selects the entire world)
-            dist_sync_fn:
-                Callback that performs the allgather operation on the metric state. When ``None``, DDP
-                will be used to perform the allgather.
-
-        Example::
-            >>> from pprint import pprint
-            >>> from torchmetrics import Accuracy, BootStrapper
-            >>> _ = torch.manual_seed(123)
-            >>> base_metric = Accuracy()
-            >>> bootstrap = BootStrapper(base_metric, num_bootstraps=20)
-            >>> bootstrap.update(torch.randint(5, (20,)), torch.randint(5, (20,)))
-            >>> output = bootstrap.compute()
-            >>> pprint(output)
-            {'mean': tensor(0.2205), 'std': tensor(0.0859)}
-
-        """
-        super().__init__(compute_on_step, dist_sync_on_step, process_group, dist_sync_fn)
+        super().__init__(compute_on_step=compute_on_step, **kwargs)
         if not isinstance(base_metric, Metric):
             raise ValueError(
                 "Expected base metric to be an instance of torchmetrics.Metric" f" but received {base_metric}"
@@ -138,7 +126,7 @@ class BootStrapper(Metric):
     def update(self, *args: Any, **kwargs: Any) -> None:
         """Updates the state of the base metric.
 
-        Any tensor passed in will be bootstrapped along dimension 0
+        Any tensor passed in will be bootstrapped along dimension 0.
         """
         for idx in range(self.num_bootstraps):
             args_sizes = apply_to_collection(args, Tensor, len)
@@ -157,8 +145,8 @@ class BootStrapper(Metric):
     def compute(self) -> Dict[str, Tensor]:
         """Computes the bootstrapped metric values.
 
-        Allways returns a dict of tensors, which can contain the following keys: ``mean``, ``std``, ``quantile`` and
-        ``raw`` depending on how the class was initialized
+        Always returns a dict of tensors, which can contain the following keys: ``mean``, ``std``, ``quantile`` and
+        ``raw`` depending on how the class was initialized.
         """
         computed_vals = torch.stack([m.compute() for m in self.metrics], dim=0)
         output_dict = {}
